"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _Bower = _interopRequireDefault(require("./Registry/Bower"));

var _Npm = _interopRequireDefault(require("./Registry/Npm"));

var _Custom = _interopRequireDefault(require("./Registry/Custom"));

var _configure = _interopRequireDefault(require("./configure"));

var _file = _interopRequireDefault(require("./file"));

var _path = _interopRequireDefault(require("path"));

var _isPlainObject = _interopRequireDefault(require("is-plain-object"));

var _util = _interopRequireDefault(require("./util"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Package {
  constructor(name, defination, options = {}) {
    this.name = name;
    this.defination = defination;
    this.options = Object.assign({
      package: null,
      flattenPackages: _configure.default.get('flattenPackages', true),
      flattenTypes: _configure.default.get('flattenTypes', false),
      flatten: _configure.default.get('flatten', false),
      override: _configure.default.get('override', true),
      registry: _configure.default.get('defaultRegistry', 'npm'),
      renames: {},
      replaces: {},
      dest: _configure.default.get('dest', 'assets'),
      path: _configure.default.get('path', '${dest}/${type}/${package}/${file}')
    }, options);

    switch (this.options.registry) {
      case 'bower':
        this.registry = new _Bower.default();
        break;

      case 'npm':
        this.registry = new _Npm.default();
        break;

      default:
        this.registry = new _Custom.default(this.options.registry);
        break;
    }

    this.path = this.registry.getPackagePath(this.name);
    this.globs = {};
  }

  isInstalled() {
    return _file.default.isDirectory(this.path, {
      cwd: _configure.default.get('cwd', process.cwd())
    });
  }

  hasDirectory(directory) {
    return _file.default.isDirectory(_path.default.join(this.path, directory), {
      cwd: _configure.default.get('cwd', process.cwd())
    });
  }

  getDests() {
    if (this.dests) {
      return this.dests;
    }

    let dests = _util.default.parseOptions(this.options, 'dest');

    this.dests = Object.assign(this.options.dests || {}, dests);
    return this.dests;
  }

  getPaths() {
    if (this.paths) {
      return this.paths;
    }

    let paths = _util.default.parseOptions(this.options, 'path');

    this.paths = Object.assign(this.options.paths || {}, paths);
    return this.paths;
  }

  getMainFiles() {
    this.mainFiles = this.registry.getPackageMainFiles(this.name);
    return this.mainFiles;
  }

  getFilesByType(type) {
    if (type in this.getTypedFiles()) {
      return this.typedFiles[type];
    }

    return [];
  }

  getFiles(options = {}) {
    if (this.files) {
      return this.files;
    }

    this.files = this.registry.getPackageFiles(this.name, options);
    return this.files;
  }

  getTypedFiles() {
    if (this.typedFiles) {
      return this.typedFiles;
    }

    let defination = this.defination;

    if (defination === true) {
      this.typedFiles = this.registry.getPackageTypedFiles(this.name, {
        main: true
      });
    } else if (typeof defination === 'string' || Array.isArray(defination)) {
      let globs = this.getGlobsFromDefination(defination);
      this.typedFiles = this.registry.getPackageTypedFiles(this.name, {
        main: false,
        globs: globs
      });
    } else if ((0, _isPlainObject.default)(defination)) {
      let types = {};

      for (let type in defination) {
        types[type] = this.getGlobsFromDefination(defination[type]);

        if ((0, _isPlainObject.default)(types[type])) {
          types[type] = [];

          for (let file in defination[type]) {
            types[type].push(defination[type][file]);
            this.options.renames[_path.default.basename(defination[type][file])] = file;
          }
        }
      }

      this.typedFiles = this.registry.getPackageTypedFiles(this.name, {
        types: types,
        main: false
      });
    }

    return this.typedFiles;
  }

  getGlobsFromDefination(defination) {
    if (typeof defination === 'string' && this.hasDirectory(defination)) {
      return `${defination}/**/*`;
    }

    return defination;
  }

  getGlobByType(type) {
    if (typeof this.globs[type] === 'undefined') {
      let glob = '.';
      let defination = this.defination;

      if (defination === true) {
        glob = '.';
      } else if (typeof defination === 'string' || Array.isArray(defination)) {
        glob = this.getGlobsFromDefination(defination);
      } else if ((0, _isPlainObject.default)(defination)) {
        if (type in defination) {
          glob = this.getGlobsFromDefination(defination[type]);

          if ((0, _isPlainObject.default)(glob)) {
            glob = '.';
          }
        } else {
          glob = '.';
        }
      }

      this.globs[type] = glob;
    }

    return this.globs[type];
  }

  getPath() {
    return this.registry.getPackagePath(this.name);
  }

  getInfo(key) {
    return this.registry.getPackageInfo(this.name, key);
  }

  getInstallCmd() {
    return this.registry.getPackageInstallCmd(this.name);
  }

}

var _default = Package;
exports.default = _default;
module.exports = exports.default;