"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _assert = _interopRequireDefault(require("assert"));

var _path = _interopRequireDefault(require("path"));

var _finder = _interopRequireDefault(require("./finder"));

var _configure = _interopRequireDefault(require("./configure"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Registry
 */
class Registry {
  constructor(options = {}) {
    this.options = Object.assign({
      cwd: _configure.default.get('cwd', process.cwd()),
      dir: null
    }, options);
    (0, _assert.default)(_path.default.isAbsolute(this.options.cwd || ''), 'options.cwd must be an absolute path');
    this.relative = _path.default.relative(process.cwd(), this.options.cwd);
  }

  getPackageMainFiles(packageName) {
    const info = this.getPackageInfo(packageName);

    if (info && info.main) {
      if (typeof info.main === 'string') {
        return [info.main];
      }

      return info.main;
    }

    return [];
  }

  getPackageFiles(packageName, options = {}) {
    return _finder.default.listFiles(this.getRelativePackagePath(packageName), '**/*', options);
  }

  getPackageTypedFiles(packageName, options = {}) {
    options = Object.assign({
      main: false,
      globs: null,
      types: _configure.default.get('types')
    }, options);
    let main = options.main;
    let types = options.types;
    let globs = options.globs;
    delete options.main;
    delete options.types;
    delete options.glob;
    let dir = this.getRelativePackagePath(packageName);

    if (main === true) {
      let files = this.getPackageMainFiles(packageName);
      return _finder.default.classifyFiles(files, types, options);
    }

    if (globs) {
      if (!Array.isArray(globs)) {
        globs = [globs];
      }

      return _finder.default.classifyFilesFromGlobs(dir, globs, types, options);
    }

    return _finder.default.classifyFilesFromDir(dir, types, options);
  }

  getPackagePath(packageName) {
    return _path.default.join(this.options.dir, packageName);
  }

  getRelativePackagePath(packageName) {
    return _path.default.join(this.relative, this.options.dir, packageName);
  }

}

var _default = Registry;
exports.default = _default;
module.exports = exports.default;