"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _assert = _interopRequireDefault(require("assert"));

var _Registry = _interopRequireDefault(require("../Registry"));

var _file = _interopRequireDefault(require("../file"));

var _path = _interopRequireDefault(require("path"));

var _configure = _interopRequireDefault(require("../configure"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class Custom extends _Registry.default {
  constructor(name, options = {}) {
    super(options);
    Object.assign(this.options, {
      json: 'package.json',
      dir: _configure.default.get(`registry.${name}.dir`, null),
      overrides: {}
    }, options);
    (0, _assert.default)(this.options.dir !== null, 'options.dir must not be empty');
    this.name = name;
  }

  getPackageInfo(packageName, key) {
    let packagePath = this.getRelativePackagePath(packageName);

    if (!_file.default.isDirectory(packagePath)) {
      return {};
    }

    let infoPath = _path.default.join(packagePath, this.options.json);

    let info = {};

    if (_file.default.exists(infoPath)) {
      info = _file.default.readJSON(infoPath);
    } else {
      info = {
        name: packageName
      };
    }

    if (typeof key !== 'undefined') {
      if (Object.hasOwnProperty.call(info, key)) {
        return info[key];
      }

      return undefined;
    }

    return info;
  }

  getPackageInstallCmd(packageName) {
    let packagePath = this.getRelativePackagePath(packageName);
    return `check ${packagePath} path`;
  }

}

var _default = Custom;
exports.default = _default;
module.exports = exports.default;