"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _globby = _interopRequireDefault(require("globby"));

var _types = _interopRequireDefault(require("./types"));

var _minimatch = _interopRequireDefault(require("minimatch"));

var _deepExtend = _interopRequireDefault(require("deep-extend"));

var _configure = _interopRequireDefault(require("./configure"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Finder
 */
class Finder {
  classifyFilesFromGlobs(dir, globs, types, options = {}) {
    if (!types) {
      types = _configure.default.get('types', _types.default);
    }

    let result = {};
    let files = this.listFiles(dir, globs, options);

    for (let type of Object.keys(types)) {
      options = (0, _deepExtend.default)({
        matchBase: true
      }, options);
      result[type] = files.filter(_minimatch.default.filter(types[type], options));
    }

    return result;
  }

  classifyFilesFromDir(dir, types, options = {}) {
    if (!types) {
      types = _configure.default.get('types', _types.default);
    }

    let result = {};

    for (let type of Object.keys(types)) {
      result[type] = this.filterFilesByType(dir, type, types, options);
    }

    return result;
  }

  classifyFiles(files, types, options = {}) {
    if (!types) {
      types = _configure.default.get('types', _types.default);
    }

    let result = {};

    if (!Array.isArray(files)) {
      files = [files];
    }

    for (let type of Object.keys(types)) {
      options = (0, _deepExtend.default)({
        matchBase: true
      }, options);
      result[type] = files.filter(_minimatch.default.filter(types[type], options));
    }

    return result;
  }

  listFiles(dir, glob = '**/*', options = {}) {
    options = (0, _deepExtend.default)({
      dot: true,
      ignore: ['.*', 'bower_components', 'node_modules']
    }, options);
    return this.filterFiles(dir, glob, options);
  }

  filterFiles(dir, filter, options = {}) {
    options = Object.assign({
      cwd: dir,
      onlyFiles: true
    }, options);
    return _globby.default.sync(filter, options);
  }

  filterFilesByType(dir, type, types, options = {}) {
    if (!types) {
      types = _configure.default.get('types', _types.default);
    }

    options = (0, _deepExtend.default)({
      matchBase: true
    }, options);
    return this.filterFiles(dir, types[type], options);
  }

}

const finder = new Finder();
var _default = finder;
exports.default = _default;
module.exports = exports.default;